# tplearn: tropical-based calculation

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

-------

**tplearn** is a Python module for tropical algebra.

## Installation

```sh
# PyPI
pip install tplearn
```

## License

**tplearn** is avaiable under an MIT license.
